"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.astMerge = void 0;
function astMerge() {
    var asts = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        asts[_i] = arguments[_i];
    }
    var mergedAST = {
        kind: 'root',
        name: 'merged',
        absPath: 'merged',
        children: {},
    };
    asts.forEach(function (ast) {
        mergedAST.name += "; ".concat(ast.name);
        mergedAST.absPath += "; ".concat(ast.absPath);
        // merge rootTypes
        Object.keys(ast.children).forEach(function (key) {
            var rootName = key;
            var rootTypeNode = ast.children[rootName];
            var mergedRootTypeAST = mergedAST.children[rootName];
            if (!mergedRootTypeAST) {
                mergedRootTypeAST = {
                    kind: 'rootType',
                    name: rootTypeNode.name,
                    absPath: 'merged',
                    children: {},
                };
                mergedAST.children[rootName] = mergedRootTypeAST;
            }
            mergedRootTypeAST.absPath += "; ".concat(rootTypeNode.absPath);
            // maybe in future namespaceConfig will be refactored
            // but now it just take last one
            if (rootTypeNode.namespaceConfig) {
                mergedRootTypeAST.namespaceConfig = rootTypeNode.namespaceConfig;
            }
            mergedRootTypeAST.children = mergeChildren(mergedRootTypeAST.children, rootTypeNode.children);
        });
    });
    return mergedAST;
}
exports.astMerge = astMerge;
function mergeChildren(target, source) {
    var result = __assign({}, target);
    Object.keys(source).forEach(function (key) {
        var targetChild = target[key];
        var sourceChild = source[key];
        if (!targetChild) {
            // add new key from source
            result[key] = sourceChild;
        }
        else if (targetChild.kind === 'dir') {
            if (sourceChild.kind === 'dir') {
                // merge dirs
                var mergedDirNode = __assign(__assign({}, targetChild), { absPath: "merged; ".concat(targetChild.absPath, "; ").concat(sourceChild.absPath), children: mergeChildren(targetChild.children, sourceChild.children) });
                if (sourceChild.namespaceConfig) {
                    mergedDirNode.namespaceConfig = sourceChild.namespaceConfig;
                }
                result[key] = mergedDirNode;
            }
            else if (sourceChild.kind === 'file') {
                // replace dir by file from source
                result[key] = sourceChild;
            }
        }
        else if (targetChild.kind === 'file') {
            // replace file by any source type
            result[key] = sourceChild;
        }
    });
    return result;
}
//# sourceMappingURL=astMerge.js.map