import { SchemaComposer } from 'graphql-compose';
import { AstRootTypeNode, AstDirNode, AstFileNode, AstRootNode } from './directoryToAst';
import { VisitInfo } from './VisitInfo';
/**
 * Do not traverse children, and go to next sibling.
 */
export declare const VISITOR_SKIP_CHILDREN = false;
/**
 * Remove Node from AST and do not traverse children.
 */
export declare const VISITOR_REMOVE_NODE: any;
export declare type VisitorEmptyResult = void | typeof VISITOR_REMOVE_NODE | typeof VISITOR_SKIP_CHILDREN;
export declare type VisitKindFn<TNode extends AstDirNode | AstFileNode | AstRootTypeNode> = (
/** Info & helper functions from visitor during traversing AST tree */
info: VisitInfo<TNode>) => VisitorEmptyResult | TNode;
/**
 * Functions for every type of AST nodes which will be called by visitor.
 */
export declare type AstVisitor = {
    DIR?: VisitKindFn<AstDirNode>;
    FILE?: VisitKindFn<AstFileNode>;
    ROOT_TYPE?: VisitKindFn<AstRootTypeNode>;
};
/**
 * Traverse AST for applying modifications to DIRs, FILEs & ROOT_TYPEs
 * Useful for writing middlewares which transform FieldConfigs entrypoints.
 *
 * @example
 *   const ast = directoryToAst(module);
 *   astVisitor(ast, schemaComposer, {
 *     ROOT_TYPE: () => {}, // run for query, mutation, subscription
 *     DIR: () => {}, // executes on visiting DIR node
 *     FILE: () => {}, // executes on visiting FILE node
 *   });
 */
export declare function astVisitor(ast: AstRootNode, schemaComposer: SchemaComposer<any>, visitor: AstVisitor): void;
export declare function visitNode(info: VisitInfo<AstDirNode | AstFileNode | AstRootTypeNode>, visitor: AstVisitor): void;
export declare function forEachKey<V>(obj: Record<string, V>, callback: (value: V, key: string) => void): void;
//# sourceMappingURL=astVisitor.d.ts.map